#
# Cookbook:: arcgis-aws2
# Recipe:: datastore
#
# Copyright:: 2018, The Authors, All Rights Reserved.

if node['platform'] == 'windows'
  arcgis_enterprise_datastore 'Update ArcGIS Data Store service logon account' do
    install_dir node['arcgis']['data_store']['install_dir']
    run_as_user node['arcgis']['run_as_user']
    run_as_password node['arcgis']['run_as_password']
    only_if { Utils.product_installed?(node['arcgis']['data_store']['product_code']) }
    subscribes :update_account, "user[#{node['arcgis']['run_as_user']}]", :immediately
    action :nothing
  end
end

arcgis_enterprise_datastore "Install System Requirements:#{recipe_name}" do
  action :system
  only_if { node['arcgis']['data_store']['install_system_requirements'] }
end

arcgis_enterprise_datastore 'Unpack ArcGIS Data Store' do
  setup_archive node['arcgis']['data_store']['setup_archive']
  setups_repo node['arcgis']['repository']['setups']
  run_as_user node['arcgis']['run_as_user']
  only_if { ::File.exist?(node['arcgis']['data_store']['setup_archive']) &&
            !::File.exist?(node['arcgis']['data_store']['setup']) }
  if node['platform'] == 'windows'
    not_if { Utils.product_installed?(node['arcgis']['data_store']['product_code']) }
  else
    not_if { EsriProperties.product_installed?(node['arcgis']['run_as_user'],
                                               node['hostname'],
                                               node['arcgis']['version'],
                                               :ArcGISDataStore) }
  end
  action :unpack
end

arcgis_enterprise_datastore 'Install ArcGIS Data Store' do
  setup node['arcgis']['data_store']['setup']
  product_code node['arcgis']['data_store']['product_code']
  install_dir node['arcgis']['data_store']['install_dir']
  data_dir node['arcgis']['data_store']['data_dir']
  run_as_user node['arcgis']['run_as_user']
  run_as_password node['arcgis']['run_as_password']
  if node['platform'] == 'windows'
    not_if { Utils.product_installed?(node['arcgis']['data_store']['product_code']) }
  else
    not_if { EsriProperties.product_installed?(node['arcgis']['run_as_user'],
                                               node['hostname'],
                                               node['arcgis']['version'],
                                               :ArcGISDataStore) }
  end
  action :install
end

ruby_block 'Configure ArcGIS Data Store log location' do
  log_file = "#{node['arcgis']['data_store']['install_dir']}\\framework\\etc\\arcgis-logsettings.json"
  block do
    file = Chef::Util::FileEdit.new(log_file)
    file.search_file_replace_line("logDir", "  \"logDir\": \"#{node['ds_log']}\",")
    file.write_file
  end
  not_if { ::File.open(log_file).lines.any?{|line| line.include?(node['ds_log'])} }
  only_if { ::File.exist?(log_file) }
end

ruby_block 'Configure ArcGIS Data Store data location' do
  log_file = "#{node['arcgis']['data_store']['install_dir']}\\etc\\arcgis-data-store-config.properties"
  block do
    file = Chef::Util::FileEdit.new(log_file)
    file.search_file_replace_line('dir.data', "dir.data=#{node['ds_content']}")
    file.write_file
  end
  not_if { ::File.open(log_file).lines.any?{|line| line.include?(node['ds_content'])} }
end

dsc_resource 'Change ArcGIS Data Store Service Startup Type' do
  resource :Service
  property :Name, 'ArcGIS Data Store'
  property :StartupType, 'Manual'
  property :State, 'Stopped'
  property :Ensure, 'Present'
end

arcgis_enterprise_datastore 'Stop ArcGIS Data Store' do
  action :stop
end

