#
# Cookbook:: arcgis-aws2
# Recipe:: desktop
#
# Copyright:: 2018, The Authors, All Rights Reserved.


case node['platform']
when 'windows'
  arcgis_desktop_desktop 'Verify ArcGIS Desktop system requirements' do
    action :system
  end

  arcgis_desktop_desktop 'Unpack ArcGIS Desktop Setup' do
    setup_archive node['arcgis']['desktop']['setup_archive']
    setups_repo node['arcgis']['repository']['setups']
    only_if { ::File.exist?(node['arcgis']['desktop']['setup_archive']) &&
              !::File.exist?(node['arcgis']['desktop']['setup']) }
    not_if { Utils.product_installed?(node['arcgis']['desktop']['product_code']) }
    action :unpack
  end

  arcgis_desktop_desktop 'Install ArcGIS Desktop' do
    setup node['arcgis']['desktop']['setup']
    product_code node['arcgis']['desktop']['product_code']
    install_dir node['arcgis']['desktop']['install_dir']
    python_dir node['arcgis']['python']['install_dir']
    install_features node['arcgis']['desktop']['install_features']
    esri_license_host node['arcgis']['desktop']['esri_license_host']
    software_class node['arcgis']['desktop']['software_class']
    seat_preference node['arcgis']['desktop']['seat_preference']
    desktop_config node['arcgis']['desktop']['desktop_config']
    modifyflexdacl node['arcgis']['desktop']['modifyflexdacl']
    not_if { Utils.product_installed?(node['arcgis']['desktop']['product_code']) }
    action :install
  end

  directory node['roam_localhost_dir'] do
    recursive true
    action :create
    only_if { node['s3_access'] }
  end

  # Download SDE Database files
  %w{
  LOCALHOST.GDS
  localhost-egdb.sde
  localhost-geodata.sde
  }.each do |file|
    aws_s3_file "#{node['roam_localhost_dir']}\\#{file}" do
      bucket node['s3_bucket']
      remote_path "#{node['s3_basescripts_windows']}/#{file}"
      region node['s3_bucket_region']
      not_if { ::File.exists?("#{node['roam_localhost_dir']}\\#{file}") }
      only_if { node['s3_access'] }
    end
  end

  windows_shortcut 'Create ArcGIS Desktop ArcCatalog Link Desktop' do
    shortcut_name 'C:\\Users\\Administrator\\Desktop\\ArcCatalog.lnk'
    target "C:/Program Files (x86)/ArcGIS/Desktop#{node['arcgis']['short_version']}/bin/ArcCatalog.exe"
  end

  windows_shortcut 'Create ArcGIS Desktop ArcMap Link Desktop' do
    shortcut_name 'C:\\Users\\Administrator\\Desktop\\ArcMap.lnk'
    target "C:/Program Files (x86)/ArcGIS/Desktop#{node['arcgis']['short_version']}/bin/ArcMap.exe"
  end
else
  Chef::Log.warn('This platform is not yet supported!')
end
