#
# Cookbook:: arcgis-aws2
# Recipe:: firewall
#
# Copyright:: 2018, The Authors, All Rights Reserved.

case node['platform']
when 'windows'
  powershell_script 'Configure Firewall' do
    code <<-EOH
      #Enabling Windows Firewall
      netsh advfirewall set allprofiles state on
      #Opening ports
      netsh advfirewall firewall add rule name="Allow_ArcGISServer_Ports" dir=in action=allow protocol=TCP localport="6080,4008,1098,2182,2190,2443,9876,29080,29081,6099,6443,4000-4007,7077,56540-56550" description="Allows connections through all ports used by ArcGIS Server"
      netsh advfirewall firewall add rule name="Allow_ArcGIS_Big_DataStore_Ports" dir=in action=allow protocol=TCP localport="9220,9320" description="Allows connections through all ports used by ArcGIS Big Data Store"
      netsh advfirewall firewall add rule name="Allow_ArcGISGeoEvent_Ports" dir=in action=allow protocol=TCP localport="2181,27271,27272,27273,6143,6180,5565,5570" description="Allows connections through all ports used by ArcGIS GeoEvent"
      netsh advfirewall firewall add rule name="Allow_Portal_Ports" dir=in action=allow protocol=TCP localport="5701,5702,7080,7443,7005,7099,7199,7654,7120,7220,7320,57900,57800,57950,57975" description="Allows connections through all ports used by Portal"
      netsh advfirewall firewall add rule name="Allow_Chef_Ports" dir=in action=allow protocol=TCP localport="8080,8443" description="Allows connections through all ports used by Chef"
      netsh advfirewall firewall add rule name="Allow_UNC" dir=in action=allow protocol=TCP localport="138" description="Allows connections to Microsoft SQL Server"
      netsh advfirewall firewall add rule name="Allow_UDP_Port_1434" dir=in action=allow protocol=UDP localport="1434" description="Allows connections through the MSSQL SQL Server monitor port"
      #This firewall will change depending on Express or Server
      netsh advfirewall firewall add rule name="Allow_SqlServer" dir=out action=allow program="%ProgramFiles%\\Microsoft SQL Server\\MSSQL10_50.SQLEXPRESS\\MSSQL\\Binn\\sqlservr.exe" description="Allow Sql Express"
      NETSH advfirewall firewall add rule name="Allow_IE" dir=out program="%ProgramFiles% (x86)\\Internet Explorer\\iexplore.exe" action="allow" enable="yes" description="Allow Internet Explorer to access internet"
      NETSH advfirewall firewall add rule name="Allow_Python" dir=out program="%SystemDrive%\\PYTHON27\\ArcGISx6410.6\\python.exe" action="allow" enable="yes" description="Allow Python for Replication to work"
      NETSH advfirewall firewall add rule name="Allow_ServerFramework_Javaw" dir=out program="%ProgramFiles%\\ArcGIS\\Server\\framework\\runtime\\jre\\bin\\javaw.exe" action="allow" enable="yes" description="For ArcGIS server to be able to make a cluster, connecting to other machines, Allow outbound connections for javaw.exe"
      NETSH advfirewall firewall add rule name="Allow_ServerFramework_Java" dir=out program="%ProgramFiles%\\ArcGIS\\Server\\framework\\runtime\\jre\\bin\\java.exe" action="allow" enable="yes" description="For ArcGIS server to be able to make a cluster, connecting to other machines, Allow outbound connections for java.exe"
      NETSH advfirewall firewall add rule name="Allow_ArcGISServer_NodeAgent" dir=out program="%ProgramFiles%\\ArcGIS\\Server\\framework\\etc\\service\\bin\\ArcGISServer.exe" action="allow" enable="yes" description="Allow ArcGISServer NodeAgent"
      NETSH advfirewall firewall add rule name="Allow_ArcGISServerProcess_rmid" dir=out program="%ProgramFiles%\\ArcGIS\\Server\\framework\\runtime\\jre\\bin\\rmid.exe" action="allow" enable="yes" description="Allow remote message invocation (communication between processes)"
      NETSH advfirewall firewall add rule name="Allow_ArcGISServerProcess_ConHost" dir=out program="%SystemRoot%\\System32\\conhost.exe" action="allow" enable="yes" description="Allow console process used by java.exe"
      NETSH advfirewall firewall add rule name="Allow_Cmd" dir=out program="%SystemRoot%\\System32\\cmd.exe" action="allow" enable="yes" description="Allows Command Line"
      NETSH advfirewall firewall add rule name="Allow_Powershell" dir=out program="%SystemRoot%\\System32\\WindowsPowerShell\\v1.0\\powershell.exe" remoteip="169.254.169.254" action="allow" enable="yes" description="Allows Powershell"
      netsh advfirewall firewall add rule name="Allow_Config" dir=out action=allow program="%ProgramFiles%\\Amazon\\Ec2ConfigService\\Ec2Config.exe" description="Allow EC2 Config to access meta data"
      netsh advfirewall firewall add rule name="Allow_Config_Wallpaper" dir=out action=allow program="%ProgramFiles%\\Amazon\\Ec2ConfigService\\Ec2WallpaperInfo.exe" description="Allow EC2 Config to access Wallpaper Settings"
      netsh advfirewall firewall add rule name="Allow_Config_Wallpaper" dir=in action=allow program="%ProgramFiles%\\Amazon\\Ec2ConfigService\\Ec2WallpaperInfo.exe" description="Allow EC2 Config to access Wallpaper Settings"
      netsh advfirewall firewall add rule name="Allow_Config_Setting" dir=in action=allow program="%ProgramFiles%\\Amazon\\Ec2ConfigService\\Ec2ConfigServiceSettings.exe" description="Allow EC2 Config to access instance info"
      netsh advfirewall firewall add rule name="Allow_Config_Setting" dir=out action=allow program="%ProgramFiles%\\Amazon\\Ec2ConfigService\\Ec2ConfigServiceSettings.exe" description="Allow EC2 Config to access instance info"
      NETSH advfirewall firewall add rule name="Allow_WindowsUpdate" dir=out program="%SystemRoot%\\System32\\svchost.exe" service="wuauserv" action="allow" enable="yes" description="Allow_WindowsUpdate"
      NETSH advfirewall firewall add rule name="Allow_TimeSync" dir=out program="%SystemRoot%\\System32\\svchost.exe" protocol="UDP" localport="123" action="allow" enable="yes" description="Allow_TimeSync"
      NETSH advfirewall firewall add rule name="Allow_IE64" dir=out program="%ProgramFiles%\\Internet Explorer\\iexplore.exe" action="allow" enable="yes" description="Allow Internet Explorer 64bit to access internet"

      #Programs Under "C:\\Program Files (x86)\\ArcGIS\\Desktop10.2\\bin\\"
      NETSH advfirewall firewall add rule name="Allow_aisdtsp2a" dir=out program="C:\\Program Files (x86)\\ArcGIS\\Desktop10.6\\bin\\aisdtsp2a.exe" action="allow" enable="yes" description="Allow aisdtsp2a to make outbound connections"
      NETSH advfirewall firewall add rule name="Allow_aisdtsr2g" dir=out program="C:\\Program Files (x86)\\ArcGIS\\Desktop10.6\\bin\\aisdtsr2g.exe" action="allow" enable="yes" description="Allow aisdtsr2g to make outbound connections"
      NETSH advfirewall firewall add rule name="Allow_AppESRIPrintLocal" dir=out program="C:\\Program Files (x86)\\ArcGIS\\Desktop10.6\\bin\\AppESRIPrintLocal.exe" action="allow" enable="yes" description="Allow AppESRIPrintLocal to make outbound connections"
      NETSH advfirewall firewall add rule name="Allow_AppROT" dir=out program="C:\\Program Files (x86)\\ArcGIS\\Desktop10.6\\bin\\AppROT.exe" action="allow" enable="yes" description="Allow AppROT to make outbound connections"
      NETSH advfirewall firewall add rule name="Allow_ArcCatalog" dir=out program="C:\\Program Files (x86)\\ArcGIS\\Desktop10.6\\bin\\ArcCatalog.exe" action="allow" enable="yes" description="Allow ArcCatalog to make outbound connections"
      NETSH advfirewall firewall add rule name="Allow_ArcGlobe" dir=out program="C:\\Program Files (x86)\\ArcGIS\\Desktop10.6\\bin\\ArcGlobe.exe" action="allow" enable="yes" description="Allow ArcGlobe to make outbound connections"
      NETSH advfirewall firewall add rule name="Allow_ArcMap" dir=out program="C:\\Program Files (x86)\\ArcGIS\\Desktop10.6\\bin\\ArcMap.exe" action="allow" enable="yes" description="Allow ArcMap to make outbound connections"
      NETSH advfirewall firewall add rule name="Allow_ArcScene" dir=out program="C:\\Program Files (x86)\\ArcGIS\\Desktop10.6\\bin\\ArcScene.exe" action="allow" enable="yes" description="Allow ArcScene to make outbound connections"
      NETSH advfirewall firewall add rule name="Allow_avmifshp" dir=out program="C:\\Program Files (x86)\\ArcGIS\\Desktop10.6\\bin\\avmifshp.exe" action="allow" enable="yes" description="Allow avmifshp to make outbound connections"
      NETSH advfirewall firewall add rule name="Allow_Categories" dir=out program="C:\\Program Files (x86)\\ArcGIS\\Desktop10.6\\bin\\Categories.exe" action="allow" enable="yes" description="Allow Categories to make outbound connections"
      NETSH advfirewall firewall add rule name="Allow_DesktopIndexingService" dir=out program="C:\\Program Files (x86)\\ArcGIS\\Desktop10.6\\bin\\DesktopIndexingService.exe" action="allow" enable="yes" description="Allow DesktopIndexingService to make outbound connections"
      NETSH advfirewall firewall add rule name="Allow_DesktopThumbnailUpdatingService" dir=out program="C:\\Program Files (x86)\\ArcGIS\\Desktop10.6\\bin\\DesktopThumbnailUpdatingService.exe" action="allow" enable="yes" description="Allow DesktopThumbnailUpdatingService to make outbound connections"
      NETSH advfirewall firewall add rule name="Allow_import71" dir=out program="C:\\Program Files (x86)\\ArcGIS\\Desktop10.6\\bin\\import71.exe" action="allow" enable="yes" description="Allow import71 to make outbound connections"
      NETSH advfirewall firewall add rule name="Allow_mp" dir=out program="C:\\Program Files (x86)\\ArcGIS\\Desktop10.6\\bin\\mp.exe" action="allow" enable="yes" description="Allow mp to make outbound connections"
      NETSH advfirewall firewall add rule name="Allow_SchematicDatasetEditor" dir=out program="C:\\Program Files (x86)\\ArcGIS\\Desktop10.6\\bin\\SchematicDatasetEditor.exe" action="allow" enable="yes" description="Allow SchematicDatasetEditor to make outbound connections"
      NETSH advfirewall firewall add rule name="Allow_SHAPEDXF" dir=out program="C:\\Program Files (x86)\\ArcGIS\\Desktop10.6\\bin\\SHAPEDXF.exe" action="allow" enable="yes" description="Allow SHAPEDXF to make outbound connections"
      NETSH advfirewall firewall add rule name="Allow_shpagf" dir=out program="C:\\Program Files (x86)\\ArcGIS\\Desktop10.6\\bin\\shpagf.exe" action="allow" enable="yes" description="Allow shpagf to make outbound connections"
      NETSH advfirewall firewall add rule name="Allow_aisdtslist" dir=out program="C:\\Program Files (x86)\\ArcGIS\\Desktop10.6\\bin\\aisdtslist.exe" action="allow" enable="yes" description="Allow aisdtslist to make outbound connections"
      NETSH advfirewall firewall add rule name="Allow_agfshp" dir=out program="C:\\Program Files (x86)\\ArcGIS\\Desktop10.6\\bin\\agfshp.exe" action="allow" enable="yes" description="Allow agfshp to make outbound connections"
      NETSH advfirewall firewall add rule name="Allow_RuntimeLocalServer" dir=out program="C:\\Program Files (x86)\\ArcGIS\\Desktop10.6\\bin\\RuntimeLocalServer.exe" action="allow" enable="yes" description="Allow RuntimeLocalServer to make outbound connections"
      NETSH advfirewall firewall add rule name="Allow_TextureCookerService" dir=out program="C:\\Program Files (x86)\\ArcGIS\\Desktop10.6\\bin\\TextureCookerService.exe" action="allow" enable="yes" description="Allow TextureCookerService to make outbound connections"
      NETSH advfirewall firewall add rule name="Allow_ARConfig" dir=out program="C:\\Program Files (x86)\\ArcGIS\\Desktop10.6\\bin\\ARConfig.exe" action="allow" enable="yes" description="Allow ARConfig to make outbound connections"
      NETSH advfirewall firewall add rule name="Allow_ArcReaderHost" dir=out program="C:\\Program Files (x86)\\ArcGIS\\Desktop10.6\\bin\\ArcReaderHost.exe" action="allow" enable="yes" description="Allow ArcReaderHost to make outbound connections"
      NETSH advfirewall firewall add rule name="Allow_ArcSOCP" dir=out program="C:\\Program Files (x86)\\ArcGIS\\Desktop10.6\\bin\\ArcSOCP.exe" action="allow" enable="yes" description="Allow ArcSOCP to make outbound connections"
      NETSH advfirewall firewall add rule name="Allow_ArcSOMP" dir=out program="C:\\Program Files (x86)\\ArcGIS\\Desktop10.6\\bin\\ArcSOMP.exe" action="allow" enable="yes" description="Allow ArcSOMP to make outbound connections"
      NETSH advfirewall firewall add rule name="Allow_JavaConfigTool" dir=out program="C:\\Program Files (x86)\\ArcGIS\\Desktop10.6\\bin\\JavaConfigTool.exe" action="allow" enable="yes" description="Allow JavaConfigTool to make outbound connections"
      NETSH advfirewall firewall add rule name="Allow_MakeServerStyleSet" dir=out program="C:\\Program Files (x86)\\ArcGIS\\Desktop10.6\\bin\\MakeServerStyleSet.exe" action="allow" enable="yes" description="Allow MakeServerStyleSet to make outbound connections"

      #Executables Under "C:\\Program Files\\ArcGIS\\Server\\bin\\"
      NETSH advfirewall firewall add rule name="Allow_pkill" dir=out program="C:\\Program Files\\ArcGIS\\Server\\bin\\pkill.exe" action="allow" enable="yes" description="Allow pkill to make outbound connections"
      NETSH advfirewall firewall add rule name="Allow_ServerConfigurationUtility" dir=out program="C:\\Program Files\\ArcGIS\\Server\\bin\\ServerConfigurationUtility.exe" action="allow" enable="yes" description="Allow ServerConfigurationUtility to make outbound connections"
      NETSH advfirewall firewall add rule name="Allow_ServerConfigurationUtilityUI" dir=out program="C:\\Program Files\\ArcGIS\\Server\\bin\\ServerConfigurationUtilityUI.exe" action="allow" enable="yes" description="Allow ServerConfigurationUtilityUI to make outbound connections"
      NETSH advfirewall firewall add rule name="Allow_ArcSOC" dir=out program="C:\\Program Files\\ArcGIS\\Server\\bin\\ArcSOC.exe" action="allow" enable="yes" description="Allow ArcSOC to make outbound connections"
      NETSH advfirewall firewall add rule name="Allow_DataLicInstall" dir=out program="C:\\Program Files\\ArcGIS\\Server\\bin\\DataLicInstall.exe" action="allow" enable="yes" description="Allow DataLicInstall to make outbound connections"

      #Executables Under "C:\\Program Files\\Common Files\\ArcGIS\\bin\\"
      NETSH advfirewall firewall add rule name="Allow_ArcGISConnection" dir=out program="C:\\Program Files\\Common Files\\ArcGIS\\bin\\ArcGISConnection.exe" action="allow" enable="yes" description="Allow ArcGISConnection to make outbound connections"
      NETSH advfirewall firewall add rule name="Allow_ESRIRegAsm" dir=out program="C:\\Program Files\\Common Files\\ArcGIS\\bin\\ESRIRegAsm.exe" action="allow" enable="yes" description="Allow ESRIRegAsm to make outbound connections"
      NETSH advfirewall firewall add rule name="Allow_ESRIReporter" dir=out program="C:\\Program Files\\Common Files\\ArcGIS\\bin\\ESRIReporter.exe" action="allow" enable="yes" description="Allow ESRIReporter to make outbound connections"
      NETSH advfirewall firewall add rule name="Allow_ESRIWebReporter" dir=out program="C:\\Program Files\\Common Files\\ArcGIS\\bin\\ESRIWebReporter.exe" action="allow" enable="yes" description="Allow ESRIWebReporter to make outbound connections"
      NETSH advfirewall firewall add rule name="Allow_SoftwareAuthorization" dir=out program="C:\\Program Files\\Common Files\\ArcGIS\\bin\\SoftwareAuthorization.exe" action="allow" enable="yes" description="Allow SoftwareAuthorization to make outbound connections"
      NETSH advfirewall firewall add rule name="Allow_fontSupport" dir=out program="C:\\Program Files\\Common Files\\ArcGIS\\bin\\fontSupport.exe" action="allow" enable="yes" description="Allow fontSupport to make outbound connections"


      #Executables Under "C:\\Program Files (x86)\\Common Files\\ArcGIS\\bin\\"
      NETSH advfirewall firewall add rule name="Allow_ArcGISFileHandler(x86)" dir=out program="C:\\Program Files (x86)\\Common Files\\ArcGIS\\bin\\ArcGISFileHandler.exe" action="allow" enable="yes" description="Allow ArcGISFileHandler to make outbound connections"
      NETSH advfirewall firewall add rule name="Allow_ESRIRegAddIn(x86)" dir=out program="C:\\Program Files (x86)\\Common Files\\ArcGIS\\bin\\ESRIRegAddIn.exe" action="allow" enable="yes" description="Allow ESRIRegAddIn to make outbound connections"
      NETSH advfirewall firewall add rule name="Allow_ESRIRegAsm(x86)" dir=out program="C:\\Program Files (x86)\\Common Files\\ArcGIS\\bin\\ESRIRegAsm.exe" action="allow" enable="yes" description="Allow ESRIRegAsm to make outbound connections"
      NETSH advfirewall firewall add rule name="Allow_ESRIReporter(x86)" dir=out program="C:\\Program Files (x86)\\Common Files\\ArcGIS\\bin\\ESRIReporter.exe" action="allow" enable="yes" description="Allow ESRIReporter to make outbound connections"
      NETSH advfirewall firewall add rule name="Allow_ESRIWebReporter(x86)" dir=out program="C:\\Program Files (x86)\\Common Files\\ArcGIS\\bin\\ESRIWebReporter.exe" action="allow" enable="yes" description="Allow ESRIWebReporter to make outbound connections"
      NETSH advfirewall firewall add rule name="Allow_SoftwareAuthorization(x86)" dir=out program="C:\\Program Files (x86)\\Common Files\\ArcGIS\\bin\\SoftwareAuthorization.exe" action="allow" enable="yes" description="Allow SoftwareAuthorization to make outbound connections"
      NETSH advfirewall firewall add rule name="Allow_ArcGISConnectionTest(x86)" dir=out program="C:\\Program Files (x86)\\Common Files\\ArcGIS\\bin\\ArcGISConnectionTest.exe" action="allow" enable="yes" description="Allow ArcGISConnectionTest to make outbound connections"
      NETSH advfirewall firewall add rule name="Allow_ArcGISAdmin(x86)" dir=out program="C:\\Program Files (x86)\\Common Files\\ArcGIS\\bin\\ArcGISAdmin.exe" action="allow" enable="yes" description="Allow ArcGISAdmin to make outbound connections"
      NETSH advfirewall firewall add rule name="Allow_ArcGISCacheMgr(x86)" dir=out program="C:\\Program Files (x86)\\Common Files\\ArcGIS\\bin\\ArcGISCacheMgr.exe" action="allow" enable="yes" description="Allow ArcGISCacheMgr to make outbound connections"
      NETSH advfirewall firewall add rule name="Allow_ArcGISConnection(x86)" dir=out program="C:\\Program Files (x86)\\Common Files\\ArcGIS\\bin\\ArcGISConnection.exe" action="allow" enable="yes" description="Allow ArcGISConnection to make outbound connections"
      NETSH advfirewall firewall add rule name="Allow_fontSupport(x86)" dir=out program="C:\\Program Files (x86)\\Common Files\\ArcGIS\\bin\\fontSupport.exe" action="allow" enable="yes" description="Allow fontSupport to make outbound connections"

      netsh advfirewall set allprofiles firewallpolicy "blockinbound,allowoutbound"
    EOH
  end
else
end
