#
# Cookbook:: arcgis-aws2
# Recipe:: geoevent
#
# Copyright:: 2018, The Authors, All Rights Reserved.

if node['platform'] == 'windows'
  arcgis_geoevent_geoevent 'Update ArcGISGeoEvent service logon account' do
    run_as_user node['arcgis']['run_as_user']
    run_as_password node['arcgis']['run_as_password']
    only_if { Utils.product_installed?(node['arcgis']['geoevent']['product_code']) }
    subscribes :update_account, "user[#{node['arcgis']['run_as_user']}]", :immediately
    action :nothing
  end
end

arcgis_geoevent_geoevent 'Unpack ArcGIS GeoEvent Server Setup' do
  setup_archive node['arcgis']['geoevent']['setup_archive']
  setups_repo node['arcgis']['repository']['setups']
  run_as_user node['arcgis']['run_as_user']
  only_if { ::File.exist?(node['arcgis']['geoevent']['setup_archive']) &&
            !::File.exist?(node['arcgis']['geoevent']['setup']) }
  if node['platform'] == 'windows'
    not_if { Utils.product_installed?(node['arcgis']['geoevent']['product_code']) }
  else
    not_if { EsriProperties.product_installed?(node['arcgis']['run_as_user'],
                                               node['hostname'],
                                               node['arcgis']['version'],
                                               :ArcGISGeoEvent) }
  end
  action :unpack
end

arcgis_geoevent_geoevent 'Setup ArcGIS GeoEvent Server' do
  setup node['arcgis']['geoevent']['setup']
  product_code node['arcgis']['geoevent']['product_code']
  install_dir node['arcgis']['server']['install_dir']
  run_as_user node['arcgis']['run_as_user']
  run_as_password node['arcgis']['run_as_password']
  if node['platform'] == 'windows'
    not_if { Utils.product_installed?(node['arcgis']['geoevent']['product_code']) }
  else
    not_if { EsriProperties.product_installed?(node['arcgis']['run_as_user'],
                                                node['hostname'],
                                                node['arcgis']['version'],
                                                :ArcGISGeoEvent) }
  end
  action :install
end

dsc_resource 'Change ArcGISGeoEvent Service Startup Type' do
  resource :Service
  property :Name, 'ArcGISGeoEvent'
  property :StartupType, 'Manual'
  property :State, 'Stopped'
  property :Ensure, 'Present'
end

arcgis_geoevent_geoevent 'Stop ArcGIS GeoEvent' do
  action :stop
end

arcgis_enterprise_server 'Stop ArcGIS Server' do
  action :stop
end

powershell_script 'Move GeoEvent jars' do
  code <<-EOH
    cp #{node['temp_dir']}\\aws-*.jar "C:\\Program Files\\ArcGIS\\Server\\GeoEvent\\deploy"
  EOH
  ignore_failure true
end

windows_shortcut 'Create GeoEvent Manager Link Desktop' do
  shortcut_name 'C:\\Users\\Administrator\\Desktop\\GeoEvent Manager.lnk'
  target 'C:/Program Files/ArcGIS/Server/GeoEvent/Manager.url'
  iconlocation 'C:\\Program Files\\Internet Explorer\\iexplore.exe,0'
end
