#
# Cookbook:: arcgis-aws2
# Recipe:: portal
#
# Copyright:: 2018, The Authors, All Rights Reserved.

if node['platform'] == 'windows'
  arcgis_enterprise_portal 'Update Portal for ArcGIS service logon account' do
    install_dir node['arcgis']['portal']['install_dir']
    run_as_user node['arcgis']['run_as_user']
    run_as_password node['arcgis']['run_as_password']
    only_if { Utils.product_installed?(node['arcgis']['portal']['product_code']) }
    subscribes :update_account, "user[#{node['arcgis']['run_as_user']}]", :immediately
    action :nothing
  end
end

arcgis_enterprise_portal "Install System Requirements:#{recipe_name}" do
  action :system
  only_if { node['arcgis']['portal']['install_system_requirements'] }
end

arcgis_enterprise_portal 'Unpack Portal for ArcGIS' do
  setup_archive node['arcgis']['portal']['setup_archive']
  setups_repo node['arcgis']['repository']['setups']
  run_as_user node['arcgis']['run_as_user']
  only_if { ::File.exist?(node['arcgis']['portal']['setup_archive']) &&
            !::File.exist?(node['arcgis']['portal']['setup']) }
  if node['platform'] == 'windows'
    not_if { Utils.product_installed?(node['arcgis']['portal']['product_code']) }
  else
    not_if { EsriProperties.product_installed?(node['arcgis']['run_as_user'],
                                               node['hostname'],
                                               node['arcgis']['version'],
                                               :ArcGISPortal) }
  end
  action :unpack
end

arcgis_enterprise_portal 'Install Portal for ArcGIS' do
  install_dir node['arcgis']['portal']['install_dir']
  product_code node['arcgis']['portal']['product_code']
  data_dir node['arcgis']['portal']['data_dir']
  setup node['arcgis']['portal']['setup']
  run_as_user node['arcgis']['run_as_user']
  run_as_password node['arcgis']['run_as_password']
  if node['platform'] == 'windows'
    not_if { Utils.product_installed?(node['arcgis']['portal']['product_code']) }
  else
    not_if { EsriProperties.product_installed?(node['arcgis']['run_as_user'],
                                               node['hostname'],
                                               node['arcgis']['version'],
                                               :ArcGISPortal) }
  end
  action :install
end

ruby_block 'Configure Portal for ArcGIS log location' do
  log_file = "#{node['arcgis']['portal']['install_dir']}\\framework\\etc\\arcgis-logsettings.json"
  block do
    file = Chef::Util::FileEdit.new(log_file)
    file.search_file_replace_line("logDir", "  \"logDir\": \"#{node['portal_log']}\",")
    file.write_file
  end
  not_if { ::File.open(log_file).lines.any?{|line| line.include?(node['portal_log'])} }
  only_if { ::File.exist?(log_file) }
end

dsc_resource 'Change Portal for ArcGIS Service Startup Type' do
  resource :Service
  property :Name, 'Portal for ArcGIS'
  property :StartupType, 'Manual'
  property :State, 'Stopped'
  property :Ensure, 'Present'
end

arcgis_enterprise_portal 'Stop Portal for ArcGIS' do
  action :stop
end

windows_shortcut 'Create Portal for ArcGIS Authorization Link Desktop' do
  shortcut_name 'C:\\Users\\Administrator\\Desktop\\Portal for ArcGIS Authorization.lnk'
  target 'C:/Program Files/Common Files/ArcGIS/bin/SoftwareAuthorization.exe'
  arguments "/p Portal /Ver #{node['arcgis']['short_version']}"
end
