#
# Cookbook:: arcgis-aws2
# Recipe:: server
#
# Copyright:: 2018, The Authors, All Rights Reserved.

if node['platform'] == 'windows'
  arcgis_enterprise_server 'Update ArcGIS Server service logon account' do
    install_dir node['arcgis']['server']['install_dir']
    run_as_user node['arcgis']['run_as_user']
    run_as_password node['arcgis']['run_as_password']
    only_if { Utils.product_installed?(node['arcgis']['server']['product_code']) }
    subscribes :update_account, "user[#{node['arcgis']['run_as_user']}]", :immediately
    action :nothing
  end
end

arcgis_enterprise_server "Install System Requirements:#{recipe_name}" do
  action :system
  only_if { node['arcgis']['server']['install_system_requirements'] }
end

arcgis_enterprise_server 'Unpack ArcGIS Server Setup' do
  setup_archive node['arcgis']['server']['setup_archive']
  setups_repo node['arcgis']['repository']['setups']
  run_as_user node['arcgis']['run_as_user']
  only_if { ::File.exist?(node['arcgis']['server']['setup_archive']) &&
            !::File.exist?(node['arcgis']['server']['setup']) }
  if node['platform'] == 'windows'
    not_if { Utils.product_installed?(node['arcgis']['server']['product_code']) }
  else
    not_if { EsriProperties.product_installed?(node['arcgis']['run_as_user'],
                                               node['hostname'],
                                               node['arcgis']['version'],
                                               :ArcGISServer) }
  end
  action :unpack
end

arcgis_enterprise_server 'Setup ArcGIS Server' do
  setup node['arcgis']['server']['setup']
  install_dir node['arcgis']['server']['install_dir']
  python_dir node['arcgis']['python']['install_dir']
  run_as_user node['arcgis']['run_as_user']
  run_as_password node['arcgis']['run_as_password']
  if node['platform'] == 'windows'
    not_if { Utils.product_installed?(node['arcgis']['server']['product_code']) }
  else
    not_if { EsriProperties.product_installed?(node['arcgis']['run_as_user'],
                                               node['hostname'],
                                               node['arcgis']['version'],
                                               :ArcGISServer) }
  end
  action :install
end

ruby_block 'Configure ArcGIS Server log location' do
  log_file = "#{node['arcgis']['server']['install_dir']}\\framework\\etc\\arcgis-logsettings.json"
  block do
    file = Chef::Util::FileEdit.new(log_file)
    file.search_file_replace_line("logDir", "  \"logDir\": \"#{node['server_log']}\",")
    file.write_file
  end
  not_if { ::File.open(log_file).lines.any?{|line| line.include?(node['server_log'])} }
  only_if { ::File.exist?(log_file) }
end

template "#{node['arcgis']['server']['install_dir']}\\framework\\etc\\auth_and_config.bat" do
  source 'auth_and_config.erb'
  variables(
    :version => node['arcgis']['short_version']
  )
  action :create
end

registry_key 'HKCU\\SOFTWARE\\ESRI\\ArcGIS File Handler\\Settings' do
  values [
    {
      :name => 'LayerPackageHandlerOption',
      :type => :dword,
      :data => 0
    },
    {
      :name => 'ApplicationInstanceOption',
      :type => :dword,
      :data => 0
    },
    {
      :name => 'PackageLocation',
      :type => :string,
      :data => node['data_dir']
    },
    {
      :name => 'PackageLocationOption',
      :type => :dword,
      :data => 1
    },
  ]
  recursive true
  action :create
end

powershell_package 'Install xSmbShare' do
  package_name 'xSmbShare'
end

%W{
#{node['arcgis']['server']['install_dir']}
#{node['server_directories']}\\directories
#{node['server_directories']}\\config-store
#{node['server_directories']}\\logs
}.each do |dir|
  directory "#{dir}" do
    rights :full_control, node['arcgis']['run_as_user']
    retries 3
    recursive true
    action :create
  end

  require 'pathname'

  dsc_resource "Share #{dir}" do
    resource :xSmbShare
    module_name 'xSmbShare'
    property :Name, Pathname.new(dir).basename
    property :Path, dir
    property :FullAccess, [node['arcgis']['run_as_user'], 'Administrator']
    property :Ensure, 'Present'
    not_if { dir == node['arcgis']['server']['install_dir'] }
  end
end

arcgis_enterprise_server 'Stop ArcGIS Server' do
  action :stop
end

directory 'C:\\ProgramData\\Microsoft\\Windows\\Start Menu\\Programs\\ArcGIS\\ArcGIS Server on Amazon Web Services' do
  action :create
end

windows_shortcut 'Create ArcGIS Server on AWS Help Link Start Menu' do
  shortcut_name 'C:\\ProgramData\\Microsoft\\Windows\\Start Menu\\Programs\\ArcGIS\\ArcGIS Server on Amazon Web Services\\ArcGIS Server on Amazon Web Services Help.lnk'
  target 'C:\\Program Files\\Internet Explorer\\iexplore.exe'
  arguments 'http://enterprise.arcgis.com/en/server/latest/cloud/amazon/what-is-arcgis-server-on-aws.htm'
  iconlocation 'C:\\Program Files\\Internet Explorer\\iexplore.exe,0'
end

windows_shortcut 'Create ArcGIS Server on AWS Help Link Desktop' do
  shortcut_name 'C:\\Users\\Administrator\\Desktop\\ArcGIS Server on Amazon Web Services Help.lnk'
  target 'C:\\Program Files\\Internet Explorer\\iexplore.exe'
  arguments 'http://enterprise.arcgis.com/en/server/latest/cloud/amazon/what-is-arcgis-server-on-aws.htm'
  iconlocation 'C:\\Program Files\\Internet Explorer\\iexplore.exe,0'
end

windows_shortcut 'Create ArcGIS Server Web Help Link Desktop' do
  shortcut_name 'C:\\Users\\Administrator\\Desktop\\ArcGIS Server Web Help.lnk'
  target 'C:/Program Files/ArcGIS/Server/Support/ServerWebHelp.url'
  iconlocation 'C:\\Program Files\\Internet Explorer\\iexplore.exe,0'
end

windows_shortcut 'Create ArcGIS Services Directory Link Desktop' do
  shortcut_name 'C:\\Users\\Administrator\\Desktop\\Services Directory.lnk'
  target 'C:/Program Files/Common Files/ArcGIS/Support/Shortcuts/ServicesDirectory.url'
  iconlocation 'C:\\Program Files\\Internet Explorer\\iexplore.exe,0'
end

windows_shortcut 'Create ArcGIS Server Manager Link Desktop' do
  shortcut_name 'C:\\Users\\Administrator\\Desktop\\ArcGIS Server Manager.lnk'
  target 'C:/Program Files/Common Files/ArcGIS/Support/Shortcuts/Manager.url'
  iconlocation 'C:\\Program Files\\Internet Explorer\\iexplore.exe,0'
end

windows_shortcut 'Create ArcGIS Admin Link Desktop' do
  shortcut_name 'C:\\Users\\Administrator\\Desktop\\ArcGIS Administration.lnk'
  target 'C:/Program Files (x86)/Common Files/ArcGIS/bin/ArcGISAdmin.exe'
end

windows_shortcut 'Create ArcGIS Server Authorization Desktop' do
  shortcut_name 'C:\\Users\\Administrator\\Desktop\\ArcGIS Server Authorization.lnk'
  target 'C:/Program Files/Common Files/ArcGIS/bin/SoftwareAuthorization.exe'
end
