
#
# Cookbook:: arcgis-aws2
# Recipe:: sql
#
# Copyright:: 2018, The Authors, All Rights Reserved.

include_recipe 'arcgis-aws2::_common'

case node['platform']
when 'windows'
  service 'MSSQLSERVER' do
    action :start
  end

  %W(#{node['data_dir']} #{node['geodatabase_dir']}).each do |dir|
    directory dir do
      rights \
        :full_control,
        [
          'Administrators',
          node['arcgis']['run_as_user'],
          'NETWORK Service',
          'NT Service\\MSSQLSERVER',
        ],
        :applies_to_children => true
      action :create
    end
  end

  powershell_package 'Install xSmbShare' do
    package_name 'xSmbShare'
  end

  dsc_resource "Share #{node['data_dir']}" do
    resource :xSmbShare
    module_name 'xSmbShare'
    property :Name, 'data'
    property :Path, node['data_dir']
    property :FullAccess, [node['arcgis']['run_as_user'], 'Administrator']
    property :Ensure, 'Present'
  end

  powershell_package 'Install SqlServerDsc' do
    package_name 'SqlServerDsc'
  end

  %w{Data Log}.each do |type|
    dsc_resource "Set SQL Database Default #{type} Location" do
      resource :SqlDatabaseDefaultLocation
      module_name 'SqlServerDsc'
      property :ServerName, node['machinename']
      property :InstanceName, 'MSSQLSERVER'
      property :Type, type
      property :Path, "#{node['geodatabase_dir']}\\"
      property :RestartService, true
    end
  end

  registry_key 'Authorize SDE Workgroup' do
    key 'HKLM\\SYSTEM\\CurrentControlSet\\services\MSSQLSERVER'
    values [
      {
        :name => 'ArcSDE_License',
        :type => :string,
        :data => 'sdeworkgroup,101,ecp411553139,none,1JHFD7E7J16SLAMEY120'
      },
    ]
    action :create
  end

  # TODO:
  # Switch to powershell_package when source prop and carbon 3.0 is available
  powershell_script 'Install Carbon' do
    code 'Install-Module carbon -Force -AllowClobber'
    only_if '[String]::IsNullOrEmpty((Get-Module -Name Carbon -ListAvailable))'
  end

  %w{
  HKLM\\SOFTWARE\\Microsoft\\MSSQLServer\\Client\\ConnectTo
  HKLM\\SOFTWARE\\Wow6432Node\\Microsoft\\MSSQLServer\\Client\\ConnectTo
  }.each do |key|
    registry_key key do
      action :create
    end

    # Carbon DSC Carbon_Permission uses different syntax than chef registry_key
    carbon_key = key.gsub('HKLM', 'HKLM:')

    dsc_resource "Grant #{node['arcgis']['run_as_user']} permission to edit the SQL Alias #{carbon_key}" do
      resource :Carbon_Permission
      module_name 'carbon'
      property :Identity, "#{node['machinename']}\\#{node['arcgis']['run_as_user']}"
      property :Path, carbon_key
      property :ApplyTo, 'Container'
      property :Permission, ['FullControl']
      property :Ensure, 'Present'
    end
  end

  dsc_resource 'Enable TCP' do
    resource :SqlServerNetwork
    module_name 'SqlServerDsc'
    property :ProtocolName, 'tcp'
    property :ServerName, node['machinename']
    property :InstanceName, 'MSSQLSERVER'
    property :RestartService, true
  end

  # Download SQL Express Database files
  %w{
  egdb.mdf
  egdb_log.ldf
  geodata.mdf
  geodata_log.ldf
  }.each do |file|
    aws_s3_file "#{node['geodatabase_dir']}\\#{file}" do
      bucket node['s3_bucket']
      remote_path "#{node['s3_basescripts_windows']}/#{file}"
      region node['s3_bucket_region']
      not_if { ::File.exist?("#{node['geodatabase_dir']}\\#{file}") }
    end
  end

  # Create SQL scripts for attaching geodatabases and idempotency check
  %w{
  attachGeodatabases
  getGeodatabases
  testGeodatabases
  }.each do |sql|
    template "#{node['temp_dir']}\\#{sql}.sql" do
      source "#{sql}.erb"
      variables(
        :geodatabase_dir => node['geodatabase_dir']
      )
      action :create
    end
  end

  dsc_resource 'Attach Geodatabases' do
    resource :SqlScript
    module_name 'SqlServerDsc'
    property :ServerInstance, node['machinename']
    property :SetFilePath, "#{node['temp_dir']}\\attachGeodatabases.sql"
    property :GetFilePath, "#{node['temp_dir']}\\getGeodatabases.sql"
    property :TestFilePath, "#{node['temp_dir']}\\testGeodatabases.sql"
  end

else
end

