#
# Cookbook:: arcgis-aws2
# Recipe:: system
#
# Copyright:: 2018, The Authors, All Rights Reserved.

include_recipe 'arcgis-aws2::_common'

case node['platform']
when 'windows'
  # Disable settings in registry to access Web page in IIS and query SQL
  registry_key 'HKLM\\SYSTEM\\CurrentControlSet\\Services\\lanmanserver\\parameters' do
    values [
      {
        name: 'DisableStrictNameChecking',
        type: :dword,
        data: 1,
      },
    ]
    action :create
  end

  registry_key 'HKLM\\SYSTEM\\CurrentControlSet\\Control\\Lsa' do
    values [
      {
        name: 'DisableLoopbackCheck',
        type: :dword,
        data: 1,
      },
    ]
    action :create
  end

  # Define DNS cahce settings
  registry_key 'HKLM\\SYSTEM\\CurrentControlSet\\Services\\Dnscache\\Parameters' do
    values [
      {
        name: 'MaxCacheTtl',
        type: :dword,
        data: 120,
      },
      {
        name: 'MaxNegativeCacheTtl',
        type: :dword,
        data: 120,
      },
    ]
    action :create
  end

  ### Configure extend volumes start up script ###
  startup_scripts = 'C:\\Windows\\System32\\GroupPolicy\\Machine\\Scripts\\Startup'

  directory startup_scripts do
    recursive true
    action :create
  end

  template "#{startup_scripts}\\extendVols.ps1" do
    source 'extendVols.erb'
    action :create
  end

  template "#{node['temp_dir']}\\GPOStartUp.ps1" do
    source 'GPOStartUp.erb'
    action :create
  end

  # TODO: Make resource idempotent
  powershell_script 'Add GPO ExtendVols Startup Script' do
    code <<-EOH
      . '#{node['temp_dir']}\\GPOStartUp.ps1'
      Add-GPOStartupPSScript -File "#{startup_scripts}\\extendVols.ps1"
    EOH
  end

  ######## End configure start up script ########

  windows_pagefile 'Automatically manage windows pagefile' do
    automatic_managed true
  end
when 'ubuntu'
end
